#pragma once
#ifndef Bicho_h
#define Bicho_h
#include <Arduino.h>
#include "Motor.h"
#include "ImpactSensor.h"
#include "LigthSensor.h"
//#include "UltrasonicSensor.h"
#include <Servo.h>
#define r_motor 0
#define l_motor 1

#define motor_r_s 4 //Motor Derecho
#define motor_r_e 5  //Enable
#define motor_l_s 2  //Motor Izquierdo
#define motor_l_e 3  //Enable

#define NECK 6 //118EJND                                                    

#define TRIG_ 13
#define ECHO_ 12

#define RIGHT_ANT 7
#define LEFT_ANT  8

#define SENSOR_LIGHT_IZQ  A0
#define SENSOR_LIGHT  A1
#define SENSOR_LIGHT_DER  A2
#define velt 300
/**@brief clase Bicho, corresponde a un robot funcional. */
class Bicho {
public:
	/**@brief constructor de la clase, este inicializa los componentes del robot*/
	Bicho();
	/**@brief destructor de la clase, este borra los punteros a los componentes del robot*/
	~Bicho();
	/**@brief Metodo que da potencia a los motores.
	*@param motor_index entero que indica el motor al que se quiere acceder.
	*@param vel entero correspondiente a la potencia entregada al motor.
	*/
	void motor_run(int motor_index, int vel);
	/**@brief Metodo que mueve el robot respecto a coordenadas en el plano cartesiano
	*Se puede mover en el eje x, eje y o una combinación de ambos. Una vez recibida la coordenada, el robot procesará un algoritmo
	*donde se hará girar al robot hasta posicionarse en la dirección del vector entre su posición y el vector, para luego moverse
	durante el tiempo necesario hasta llegar al punto deseado.
	*@param spd_x entero que le indica al robot moverse en el eje x del plano cartesiano.
	*@param spd_y entero que le indica al robot moverse en el eje y del plano cartesiano.
	*/
	void rbt_move(int spd_x, int spd_y);
	/**@brief Metodo que moverá al robot una distancia deseada en centimetros.
	Utilizará el sensor de ultrasonido para determinar la distancia que debe moverse.
	*/
	//void dis_thresh(byte dCM);
	/**@brief Metodo que mueve el cuello del robot.
	*@param angle angulo de movimiento del servo.
	*/
	void nk_rotate(byte angle);
	/**@brief Metodo que mueve inicializa las antenas.*/
	void rbt_ant();
	int readRightAnt();
	int readLeftAnt();
	int readLeftLight();
	int readCenterLight();
	int readRightLight();
protected: 
	/**@brief atributo correspondiente a arreglo de punteros a motores. 
	*/
	Motor* motores[2];
	/**@brief atributo correspondiente a un puntero a un objeto de la clase UltrasonicSensor. */
	//UltrasonicSensor* SensorUltrasonico;
	/**@brief atributo correspondiente a un puntero a un objeto de la clase LigthSensor, este es el sensor central. */
	LigthSensor* SensorLuzCentro;
	/**@brief atributo correspondiente a un puntero a un objeto de la clase LigthSensor, este es el sensor de la izquierda. */
	LigthSensor* SensorLuzIzq;
	/**@brief atributo correspondiente a un puntero a un objeto de la clase LigthSensor, este es el sensor de la derecha. */
	LigthSensor* SensorLuzDer;
	/**@brief atributo correspondiente a un puntero a un objeto de la clase Servo, este objeto mueve el cuello. */
	Servo* Neck;
	//rbt_ant() variables
	/**@brief atributo correspondiente a un puntero a un objeto de la clase ImpactSensor, este es la antena derecha. */
	ImpactSensor* AntenaDer;
	/**@brief atributo correspondiente a un puntero a un objeto de la clase ImpactSensor, este es la antena izquierda. */
	ImpactSensor* AntenaIzq;
	/**@brief atributo de tipo byte, corresponde a un contador con los impactos de la antena derecha. */
	byte l_crash = 0;
	/**@brief atributo de tipo byte, corresponde a un contador con los impactos de la antena izquierda. */
	byte r_crash = 0;
	/**@brief atributo de tipo unsigned int. corresponde al tiempo minimo entre dos impactos del algoritmo hormiga. */
	unsigned int ant_crash_time = 1000;
	/**@brief atributo de tipo boolean. */
	boolean t_turn = false;

};

#endif